<template>
    <div>
        <section class="withdraw">
            <FinanceSwitch/>
            <div class="input__field-group" style="margin-top: -3px;">
                <span class="input__description">Выберите систему</span>
                <div class="inbox">
                    <div class="d-flex">
                        <div class="pay-box" :class="[system == 1 ? 'isActive' : '']" @click="system = 1;comission = 3">
                            <img src="/assets/img/withdraw/qiwi.png" class="pay-img" />
                        </div>
                        <div class="pay-box" :class="[system == 2 ? 'isActive' : '']" @click="system = 2;comission = 5">
                            <img src="/assets/img/withdraw/free-kassa.png" class="pay-img" />
                        </div>
                        <div class="pay-box" :class="[system == 3 ? 'isActive' : '']" @click="system = 3;comission = 10">
                            <img src="/assets/img/withdraw/card.png" class="pay-img" />
                        </div>
                    </div>
                </div>
            </div>
            <div class="input__field-group">
                <span class="input__description">Реквизиты</span>
                <input
                    placeholder="Введите кошелек..."
                    type="text"
                    class="input__item"
                    v-model="wallet"
                />
            </div>
            <div class="input__field-group">
                <span class="input__description">Сумма</span>
                <input
                    placeholder="Введите сумму..."
                    type="text"
                    class="input__item"
                    v-model="amount"
                />
            </div>
            <div class="input__field-group total__counter" style="display: none">
                <span class="input__description">К зачислению: <b>{{ Number(total).toFixed(2) }}</b></span>
                <span class="input__description">Комиссия: <b>{{ Number(comission).toFixed(2) }}%</b></span>
            </div>
            <div class="input__field-group input__field-group_last">
                <div class="btn-primary input__submit">
                    <button
                        type="submit"
                        class="btn-primary__body"
                        :class="[loading ? 'loading' : '']"
                        @click="createWithdraw"
                    >
                        Вывести средства
                    </button>
                </div>
            </div>
        </section>
        <table class="table">
            <thead class="table__head">
                <tr class="table__head-row">
                    <td class="table__head-item">
                        ID
                    </td>
                    <td class="table__head-item">
                        Дата
                    </td>
                    <td class="table__head-item">
                        Реквизиты
                    </td>
                    <td class="table__head-item">
                        Сумма
                    </td>
                    <td class="table__head-item">
                        Статус
                    </td>
                </tr>
            </thead>
            <tbody class="table__body">
                <tr
                    class="table__body-row"
                    v-for="withdraw in withdraws"
                    :key="withdraw.id"
                >
                    <td class="table__body-item">
                        {{ withdraw.id }}
                    </td>
                    <td class="table__body-item">
                        {{ withdraw.date }}
                    </td>
                    <td class="table__body-item table__padding">
                        <img
                            :src="'/assets/img/withdraw/sm/' + withdraw.icon"
                            class="sm-withdraw"
                        />
                        {{ withdraw.wallet }}
                    </td>
                    <td class="table__body-item">
                        {{ withdraw.sum }} ₽
                    </td>
                    <td class="table__body-item table__padding">
                        <span
                            class="badge"
                            :class="[withdraw.status == 0 ? 'badge-warning' : (withdraw.status == 1 ? 'badge-success' : (withdraw.status == 3 ? 'badge-info' : 'badge-danger'))]"
                        >
                            {{ withdraw.status == 0 ? 'Ожидание' : (withdraw.status == 1 ? 'Успешно!' : (withdraw.status == 3 ? 'Обработка' : 'Отменено')) }}
                            <i 
                                class="fa fa-info-circle reason" 
                                aria-hidden="true"
                                v-show="withdraw.reason !== null"
                                @click="showReason(withdraw.reason)"
                            >
                            </i>
                        </span>
                        <span 
                            class="badge badge-danger"
                            style="margin-left: 5px;cursor:pointer;"
                            @click="declineWithdraw(withdraw.id)"
                            v-if="withdraw.status == 0"
                        >X</span>
                    </td>
                </tr>
                <tr class="table__body-row" v-if="withdraws.length == 0">
                    <td colspan="5" class="table__body-item table__padding">
                        Вы не заказывали выплату
                    </td>
                </tr>
            </tbody>
        </table>
    </div>
</template>

<script>
import FinanceSwitch from '../components/FinanceSwitch'

export default {
    components: {
        FinanceSwitch
    },
    data() {
        return {
            amount: 100,
            wallet: '',
            system: '',
            withdraws: [],
            loading: false,
            total: 100,
            comission: 0
        }
    },
    methods: {
        init() {
            this.$root.axios.post('/withdraw/get')
            .then(response => {
                const {data} = response;
                this.withdraws = data;
            })
        },
        declineWithdraw(id) {
            this.$root.axios.post('/withdraw/decline', {
                id: id
            })
            .then(response => {
                const {data} = response;

                if(data.error) {
                    return notify({
                        theme: 'red',
                        text: data.message
                    })
                }

                this.$root.user.balance = data.balance;
                this.init();
            })
        },
        createWithdraw() {
            if(this.loading) return;

            this.loading = true;
            this.$root.axios.post('/withdraw/create', {
                system: this.system,
                amount: this.amount,
                wallet: this.wallet
            })
            .then(res => {
                this.loading = false;
                const data = res.data;
                if(data.error) {
                    return notify({
                        theme: 'red',
                        text: data.message
                    })
                }

                this.$root.user.balance = data.balance;

                notify({
                    theme: 'green',
                    text: 'Выплата заказа! Ожидайте поступления в течении 24-х часов'
                })

                this.init();
            })
        },
        showReason(message) {
            return notify({
                theme: 'blue',
                text: message
            })
        }
    },
    watch: {
        amount: function () {
            this.total = this.amount - (this.amount / 100 * this.comission);
        },
        comission: function () {
            this.total = this.amount - (this.amount / 100 * this.comission);
        }
    },
    mounted() {
        this.init()
    }
}
</script>

<style scoped>
.reason {
    cursor: pointer;
    margin-left: 4px;
}
.fa-times {
    color: red;
    position: relative;
    left: -9px;
    cursor: pointer;
}
.total__counter {
    display: flex;
    justify-content: space-between;
    margin-bottom: 10px!important;
    margin-top: 10px!important;
}

.total__counter > .input__description {
    font-size: 12.5px
}

.input__description > b {
    color: #000;
    margin-left: 5px;
}

.withdraw {
    background: #fff;
    border-radius: 8px;
    padding: 50px;
    margin-bottom: 48px;
}

@media (max-width: 62em) {
    .withdraw {
        padding: 25px;
    }
}

.input__field-group {
    margin: auto;
    margin-top: 10px;
    max-width: 500px;
}

.input__field-group_last {
    margin-top: -16px;
}

.input__submit {
    min-width: 100%;
}

.input__description {
    margin-bottom: 10px;
    text-transform: uppercase;
    font-weight: 500;
    font-size: 11px;
    line-height: 16px;
    letter-spacing: 0.05em;
}

.input__item {
    padding: 16px 21px;
}

.btn-primary__body {
    padding: 23px 21px;
    text-transform: uppercase;
}

/* Создание выплат / Выбор системы */

.inbox {
    overflow: auto;
    /* padding: 5px */
}

.pay-box {
    background-color: #f7f8ff;
    border: 1px solid #edeefb;
    border-radius: 4px;
    flex: auto;
    margin-right: 15px;
    min-width: 150px;
    padding: 5px 0;
    text-align: center;
    cursor: pointer;
    transition: 0s!important;
}

.pay-box .pay-img {
    height: 70px!important;
    user-select: none;
    pointer-events: none;
}

.pay-box.isActive {
    border: 1px solid #1f50f8
}

.pay-box:last-child {
    margin: 0
}

.sm-withdraw {
    vertical-align: middle;
    width: 24px;
}

::-webkit-scrollbar {
    height: 3px;
    width: 3px
}

::-webkit-scrollbar-button {
    background-color: #fff
}

::-webkit-scrollbar-track {
    background-color: #999
}

::-webkit-scrollbar-track-piece {
    background-color: #e1e6ee
}

::-webkit-scrollbar-thumb {
    background-color: #b4b2c9;
    border-radius: 3px;
    height: 50px
}

::-webkit-scrollbar-corner {
    background-color: #999
}

::-webkit-resizer {
    background-color: #666
}
</style>
